#[repr(u8)]pub enum ProofLocation {
Private = 0,
Emitted = 1,
Swarm = 2,
Waku = 3,
Reserved = 4,
Ipfs = 5,
}Expand description
Where the Merkle proof for a conditional order is stored / communicated.
Variants
Private = 0
Proof is kept private; only the owner polls.
Emitted = 1
Proof emitted as an on-chain event.
Swarm = 2
Proof stored on Swarm.
Waku = 3
Proof communicated via Waku.
Reserved = 4
Reserved for future use.
Ipfs = 5
Proof stored on IPFS.
Implementations
Sourceimpl ProofLocation
impl ProofLocation
Sourcepub const fn as_str(self) -> &'static str
pub const fn as_str(self) -> &'static str
Returns a lowercase string label for the proof location.
Sourcepub const fn is_private(self) -> bool
pub const fn is_private(self) -> bool
Returns true if the proof is kept private (owner-polled only).
Sourcepub const fn is_emitted(self) -> bool
pub const fn is_emitted(self) -> bool
Returns true if the proof is emitted as an on-chain event.
Sourcepub const fn is_reserved(self) -> bool
pub const fn is_reserved(self) -> bool
Returns true if this location is the reserved (future-use) discriminant.